# coding: utf-8

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tech_inspection_service_client.api_client import ApiClient
from tech_inspection_service_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PointsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_point(self, **kwargs):  # noqa: E501
        """Add new point to operator  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_point(operator_id=operator_id_value, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int operator_id: Operator's Id (required)
        :param TechInspectionPointQuery tech_inspection_point_query: New point
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_point_with_http_info(**kwargs)  # noqa: E501

    def add_point_with_http_info(self, **kwargs):  # noqa: E501
        """Add new point to operator  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_point_with_http_info(operator_id=operator_id_value, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int operator_id: Operator's Id (required)
        :param TechInspectionPointQuery tech_inspection_point_query: New point
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(int, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'operator_id',
            'tech_inspection_point_query'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_point" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'operator_id' is set
        if self.api_client.client_side_validation and ('operator_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['operator_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `operator_id` when calling `add_point`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'operator_id' in local_var_params:
            path_params['operatorId'] = local_var_params['operator_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tech_inspection_point_query' in local_var_params:
            body_params = local_var_params['tech_inspection_point_query']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/techPoints/{operatorId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_point_by_id(self, **kwargs):  # noqa: E501
        """Get point by pointId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_point_by_id(point_id=point_id_value, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int point_id: Point's Id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TechInspectionPointQuery
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_point_by_id_with_http_info(**kwargs)  # noqa: E501

    def get_point_by_id_with_http_info(self, **kwargs):  # noqa: E501
        """Get point by pointId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_point_by_id_with_http_info(point_id=point_id_value, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int point_id: Point's Id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TechInspectionPointQuery, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'point_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_point_by_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'point_id' is set
        if self.api_client.client_side_validation and ('point_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['point_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `point_id` when calling `get_point_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'point_id' in local_var_params:
            path_params['pointId'] = local_var_params['point_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/techPoints/{pointId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TechInspectionPointQuery',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_points_by_coordinates(self, **kwargs):  # noqa: E501
        """Get points by location route  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_points_by_coordinates(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param float latitude:
        :param float longitude:
        :param int distance:
        :param int page_index:
        :param int page_size:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TechInspectionPointQueryQueryResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_points_by_coordinates_with_http_info(**kwargs)  # noqa: E501

    def get_points_by_coordinates_with_http_info(self, **kwargs):  # noqa: E501
        """Get points by location route  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_points_by_coordinates_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param float latitude:
        :param float longitude:
        :param int distance:
        :param int page_index:
        :param int page_size:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TechInspectionPointQueryQueryResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'latitude',
            'longitude',
            'distance',
            'page_index',
            'page_size'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_points_by_coordinates" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'latitude' in local_var_params and local_var_params['latitude'] is not None:  # noqa: E501
            query_params.append(('Latitude', local_var_params['latitude']))  # noqa: E501
        if 'longitude' in local_var_params and local_var_params['longitude'] is not None:  # noqa: E501
            query_params.append(('Longitude', local_var_params['longitude']))  # noqa: E501
        if 'distance' in local_var_params and local_var_params['distance'] is not None:  # noqa: E501
            query_params.append(('Distance', local_var_params['distance']))  # noqa: E501
        if 'page_index' in local_var_params and local_var_params['page_index'] is not None:  # noqa: E501
            query_params.append(('PageIndex', local_var_params['page_index']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('PageSize', local_var_params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/techPoints/byCoordinates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TechInspectionPointQueryQueryResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_points_by_location_route(self, **kwargs):  # noqa: E501
        """Get points by location route  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_points_by_location_route(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str location_route:
        :param int page_index:
        :param int page_size:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TechInspectionPointQueryQueryResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_points_by_location_route_with_http_info(**kwargs)  # noqa: E501

    def get_points_by_location_route_with_http_info(self, **kwargs):  # noqa: E501
        """Get points by location route  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_points_by_location_route_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str location_route:
        :param int page_index:
        :param int page_size:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TechInspectionPointQueryQueryResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'location_route',
            'page_index',
            'page_size'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_points_by_location_route" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'location_route' in local_var_params and local_var_params['location_route'] is not None:  # noqa: E501
            query_params.append(('LocationRoute', local_var_params['location_route']))  # noqa: E501
        if 'page_index' in local_var_params and local_var_params['page_index'] is not None:  # noqa: E501
            query_params.append(('PageIndex', local_var_params['page_index']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('PageSize', local_var_params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/techPoints/byRoute', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TechInspectionPointQueryQueryResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_point(self, **kwargs):  # noqa: E501
        """Remove point  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_point(point_id=point_id_value, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int point_id: Point's Id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_point_with_http_info(**kwargs)  # noqa: E501

    def remove_point_with_http_info(self, **kwargs):  # noqa: E501
        """Remove point  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_point_with_http_info(point_id=point_id_value, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int point_id: Point's Id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'point_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_point" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'point_id' is set
        if self.api_client.client_side_validation and ('point_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['point_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `point_id` when calling `remove_point`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'point_id' in local_var_params:
            path_params['pointId'] = local_var_params['point_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/techPoints/{pointId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_point(self, **kwargs):  # noqa: E501
        """Update point info  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_point(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param TechInspectionPointQuery tech_inspection_point_query: Point's new data
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_point_with_http_info(**kwargs)  # noqa: E501

    def update_point_with_http_info(self, **kwargs):  # noqa: E501
        """Update point info  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_point_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param TechInspectionPointQuery tech_inspection_point_query: Point's new data
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tech_inspection_point_query'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_point" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tech_inspection_point_query' in local_var_params:
            body_params = local_var_params['tech_inspection_point_query']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/techPoints', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from tech_inspection_service_client.api.operators_api import OperatorsApi
from tech_inspection_service_client.api.points_api import PointsApi



# coding: utf-8

# flake8: noqa

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0"

# import apis into sdk package
from tech_inspection_service_client.api.operators_api import OperatorsApi
from tech_inspection_service_client.api.points_api import PointsApi

# import ApiClient
from tech_inspection_service_client.api_client import ApiClient
from tech_inspection_service_client.configuration import Configuration
from tech_inspection_service_client.exceptions import OpenApiException
from tech_inspection_service_client.exceptions import ApiTypeError
from tech_inspection_service_client.exceptions import ApiValueError
from tech_inspection_service_client.exceptions import ApiKeyError
from tech_inspection_service_client.exceptions import ApiException
# import models into sdk package
from tech_inspection_service_client.models.error import Error
from tech_inspection_service_client.models.error_model import ErrorModel
from tech_inspection_service_client.models.problem_details import ProblemDetails
from tech_inspection_service_client.models.tech_inspection_operator_query import TechInspectionOperatorQuery
from tech_inspection_service_client.models.tech_inspection_operator_status import TechInspectionOperatorStatus
from tech_inspection_service_client.models.tech_inspection_point_query import TechInspectionPointQuery
from tech_inspection_service_client.models.tech_inspection_point_query_query_result import TechInspectionPointQueryQueryResult
from tech_inspection_service_client.models.tech_inspection_point_status import TechInspectionPointStatus




# coding: utf-8

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import tech_inspection_service_client
from tech_inspection_service_client.api.operators_api import OperatorsApi  # noqa: E501
from tech_inspection_service_client.rest import ApiException


class TestOperatorsApi(unittest.TestCase):
    """OperatorsApi unit test stubs"""

    def setUp(self):
        self.api = tech_inspection_service_client.api.operators_api.OperatorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_operator(self):
        """Test case for add_operator

        Add new operator  # noqa: E501
        """
        pass

    def test_get_operator_by_id(self):
        """Test case for get_operator_by_id

        Get operator by operatorId  # noqa: E501
        """
        pass

    def test_remove_operator(self):
        """Test case for remove_operator

        Remove operator  # noqa: E501
        """
        pass

    def test_update_operator(self):
        """Test case for update_operator

        Update operator info  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tech_inspection_service_client
from tech_inspection_service_client.models.error import Error  # noqa: E501
from tech_inspection_service_client.rest import ApiException

class TestError(unittest.TestCase):
    """Error unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Error
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tech_inspection_service_client.models.error.Error()  # noqa: E501
        if include_optional :
            return Error(
                code = '0', 
                target = '0', 
                message = '0', 
                details = [
                    tech_inspection_service_client.models.error.Error(
                        code = '0', 
                        target = '0', 
                        message = '0', 
                        details = [
                            tech_inspection_service_client.models.error.Error(
                                code = '0', 
                                target = '0', 
                                message = '0', )
                            ], )
                    ]
            )
        else :
            return Error(
        )

    def testError(self):
        """Test Error"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tech_inspection_service_client.configuration import Configuration


class TechInspectionPointQuery(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'point_id': 'int',
        'operator_id': 'int',
        'name': 'str',
        'status': 'TechInspectionPointStatus',
        'owner': 'str',
        'address': 'str',
        'address_latitude': 'float',
        'address_longitude': 'float',
        'address_route': 'str',
        'phone_numbers': 'list[str]',
        'emails': 'list[str]'
    }

    attribute_map = {
        'point_id': 'pointId',
        'operator_id': 'operatorId',
        'name': 'name',
        'status': 'status',
        'owner': 'owner',
        'address': 'address',
        'address_latitude': 'addressLatitude',
        'address_longitude': 'addressLongitude',
        'address_route': 'addressRoute',
        'phone_numbers': 'phoneNumbers',
        'emails': 'emails'
    }

    def __init__(self, point_id=None, operator_id=None, name=None, status=None, owner=None, address=None, address_latitude=None, address_longitude=None, address_route=None, phone_numbers=None, emails=None, local_vars_configuration=None):  # noqa: E501
        """TechInspectionPointQuery - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._point_id = None
        self._operator_id = None
        self._name = None
        self._status = None
        self._owner = None
        self._address = None
        self._address_latitude = None
        self._address_longitude = None
        self._address_route = None
        self._phone_numbers = None
        self._emails = None
        self.discriminator = None

        if point_id is not None:
            self.point_id = point_id
        if operator_id is not None:
            self.operator_id = operator_id
        self.name = name
        if status is not None:
            self.status = status
        self.owner = owner
        self.address = address
        self.address_latitude = address_latitude
        self.address_longitude = address_longitude
        self.address_route = address_route
        self.phone_numbers = phone_numbers
        self.emails = emails

    @property
    def point_id(self):
        """Gets the point_id of this TechInspectionPointQuery.  # noqa: E501


        :return: The point_id of this TechInspectionPointQuery.  # noqa: E501
        :rtype: int
        """
        return self._point_id

    @point_id.setter
    def point_id(self, point_id):
        """Sets the point_id of this TechInspectionPointQuery.


        :param point_id: The point_id of this TechInspectionPointQuery.  # noqa: E501
        :type: int
        """

        self._point_id = point_id

    @property
    def operator_id(self):
        """Gets the operator_id of this TechInspectionPointQuery.  # noqa: E501


        :return: The operator_id of this TechInspectionPointQuery.  # noqa: E501
        :rtype: int
        """
        return self._operator_id

    @operator_id.setter
    def operator_id(self, operator_id):
        """Sets the operator_id of this TechInspectionPointQuery.


        :param operator_id: The operator_id of this TechInspectionPointQuery.  # noqa: E501
        :type: int
        """

        self._operator_id = operator_id

    @property
    def name(self):
        """Gets the name of this TechInspectionPointQuery.  # noqa: E501


        :return: The name of this TechInspectionPointQuery.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TechInspectionPointQuery.


        :param name: The name of this TechInspectionPointQuery.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """Gets the status of this TechInspectionPointQuery.  # noqa: E501


        :return: The status of this TechInspectionPointQuery.  # noqa: E501
        :rtype: TechInspectionPointStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TechInspectionPointQuery.


        :param status: The status of this TechInspectionPointQuery.  # noqa: E501
        :type: TechInspectionPointStatus
        """

        self._status = status

    @property
    def owner(self):
        """Gets the owner of this TechInspectionPointQuery.  # noqa: E501


        :return: The owner of this TechInspectionPointQuery.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this TechInspectionPointQuery.


        :param owner: The owner of this TechInspectionPointQuery.  # noqa: E501
        :type: str
        """

        self._owner = owner

    @property
    def address(self):
        """Gets the address of this TechInspectionPointQuery.  # noqa: E501


        :return: The address of this TechInspectionPointQuery.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this TechInspectionPointQuery.


        :param address: The address of this TechInspectionPointQuery.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def address_latitude(self):
        """Gets the address_latitude of this TechInspectionPointQuery.  # noqa: E501


        :return: The address_latitude of this TechInspectionPointQuery.  # noqa: E501
        :rtype: float
        """
        return self._address_latitude

    @address_latitude.setter
    def address_latitude(self, address_latitude):
        """Sets the address_latitude of this TechInspectionPointQuery.


        :param address_latitude: The address_latitude of this TechInspectionPointQuery.  # noqa: E501
        :type: float
        """

        self._address_latitude = address_latitude

    @property
    def address_longitude(self):
        """Gets the address_longitude of this TechInspectionPointQuery.  # noqa: E501


        :return: The address_longitude of this TechInspectionPointQuery.  # noqa: E501
        :rtype: float
        """
        return self._address_longitude

    @address_longitude.setter
    def address_longitude(self, address_longitude):
        """Sets the address_longitude of this TechInspectionPointQuery.


        :param address_longitude: The address_longitude of this TechInspectionPointQuery.  # noqa: E501
        :type: float
        """

        self._address_longitude = address_longitude

    @property
    def address_route(self):
        """Gets the address_route of this TechInspectionPointQuery.  # noqa: E501


        :return: The address_route of this TechInspectionPointQuery.  # noqa: E501
        :rtype: str
        """
        return self._address_route

    @address_route.setter
    def address_route(self, address_route):
        """Sets the address_route of this TechInspectionPointQuery.


        :param address_route: The address_route of this TechInspectionPointQuery.  # noqa: E501
        :type: str
        """

        self._address_route = address_route

    @property
    def phone_numbers(self):
        """Gets the phone_numbers of this TechInspectionPointQuery.  # noqa: E501


        :return: The phone_numbers of this TechInspectionPointQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._phone_numbers

    @phone_numbers.setter
    def phone_numbers(self, phone_numbers):
        """Sets the phone_numbers of this TechInspectionPointQuery.


        :param phone_numbers: The phone_numbers of this TechInspectionPointQuery.  # noqa: E501
        :type: list[str]
        """

        self._phone_numbers = phone_numbers

    @property
    def emails(self):
        """Gets the emails of this TechInspectionPointQuery.  # noqa: E501


        :return: The emails of this TechInspectionPointQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """Sets the emails of this TechInspectionPointQuery.


        :param emails: The emails of this TechInspectionPointQuery.  # noqa: E501
        :type: list[str]
        """

        self._emails = emails

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TechInspectionPointQuery):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TechInspectionPointQuery):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import tech_inspection_service_client
from tech_inspection_service_client.api.points_api import PointsApi  # noqa: E501
from tech_inspection_service_client.rest import ApiException


class TestPointsApi(unittest.TestCase):
    """PointsApi unit test stubs"""

    def setUp(self):
        self.api = tech_inspection_service_client.api.points_api.PointsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_point(self):
        """Test case for add_point

        Add new point to operator  # noqa: E501
        """
        pass

    def test_get_point_by_id(self):
        """Test case for get_point_by_id

        Get point by pointId  # noqa: E501
        """
        pass

    def test_get_points_by_coordinates(self):
        """Test case for get_points_by_coordinates

        Get points by location route  # noqa: E501
        """
        pass

    def test_get_points_by_location_route(self):
        """Test case for get_points_by_location_route

        Get points by location route  # noqa: E501
        """
        pass

    def test_remove_point(self):
        """Test case for remove_point

        Remove point  # noqa: E501
        """
        pass

    def test_update_point(self):
        """Test case for update_point

        Update point info  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tech_inspection_service_client
from tech_inspection_service_client.models.tech_inspection_operator_status import TechInspectionOperatorStatus  # noqa: E501
from tech_inspection_service_client.rest import ApiException

class TestTechInspectionOperatorStatus(unittest.TestCase):
    """TechInspectionOperatorStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TechInspectionOperatorStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tech_inspection_service_client.models.tech_inspection_operator_status.TechInspectionOperatorStatus()  # noqa: E501
        if include_optional :
            return TechInspectionOperatorStatus(
            )
        else :
            return TechInspectionOperatorStatus(
        )

    def testTechInspectionOperatorStatus(self):
        """Test TechInspectionOperatorStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from tech_inspection_service_client.models.error import Error
from tech_inspection_service_client.models.error_model import ErrorModel
from tech_inspection_service_client.models.problem_details import ProblemDetails
from tech_inspection_service_client.models.tech_inspection_operator_query import TechInspectionOperatorQuery
from tech_inspection_service_client.models.tech_inspection_operator_status import TechInspectionOperatorStatus
from tech_inspection_service_client.models.tech_inspection_point_query import TechInspectionPointQuery
from tech_inspection_service_client.models.tech_inspection_point_query_query_result import TechInspectionPointQueryQueryResult
from tech_inspection_service_client.models.tech_inspection_point_status import TechInspectionPointStatus



# coding: utf-8

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tech_inspection_service_client
from tech_inspection_service_client.models.tech_inspection_operator_query import TechInspectionOperatorQuery  # noqa: E501
from tech_inspection_service_client.rest import ApiException

class TestTechInspectionOperatorQuery(unittest.TestCase):
    """TechInspectionOperatorQuery unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TechInspectionOperatorQuery
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tech_inspection_service_client.models.tech_inspection_operator_query.TechInspectionOperatorQuery()  # noqa: E501
        if include_optional :
            return TechInspectionOperatorQuery(
                operator_id = 56, 
                name = '0', 
                link = '0', 
                status = 'paused', 
                director_initials = '0', 
                ogrn = '0', 
                org_form = '0', 
                address = '0', 
                address_latitude = 1.337, 
                address_longitude = 1.337, 
                address_route = '0', 
                phone_numbers = [
                    '0'
                    ], 
                emails = [
                    '0'
                    ], 
                tech_inspection_points = [
                    tech_inspection_service_client.models.tech_inspection_point_query.TechInspectionPointQuery(
                        point_id = 56, 
                        operator_id = 56, 
                        name = '0', 
                        status = 'paused', 
                        owner = '0', 
                        address = '0', 
                        address_latitude = 1.337, 
                        address_longitude = 1.337, 
                        address_route = '0', 
                        phone_numbers = [
                            '0'
                            ], 
                        emails = [
                            '0'
                            ], )
                    ]
            )
        else :
            return TechInspectionOperatorQuery(
        )

    def testTechInspectionOperatorQuery(self):
        """Test TechInspectionOperatorQuery"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
